diff src/termhooks.h @ 83342:9216636c02fc

Rename `struct display' to `struct device'. Update function, parameter and variable names accordingly. * src/termhooks.h (struct device): Rename to `struct device'. Rename member `next_display' to `next_device'. Rename member `delete_display_hook' to `delete_device_hook'. (FRAME_DISPLAY): Rename to FRAME_DEVICE. (DISPLAY_ACTIVE_P): Rename to DEVICE_ACTIVE_P. (DISPLAY_TERMINAL_CODING): Rename to DEVICE_TERMINAL_CODING. (DISPLAY_KEYBOARD_CODING): Rename to DEVICE_KEYBOARD_CODING. * src/frame.h (stuct frame): Rename `display' member to `device'. * src/xterm.h (x_display_info): Rename member `frame_display' to `device'. * src/termchar.h (struct tty_display_info): Rename `display' member to `device'. * src/keyboard.c (push_display_kboard): Rename to push_device_kboard. * lisp/frame.el (make-frame): Rename frame parameter `display-id' to `device'. * src/frame.c (Fmake_terminal_frame): Ditto. * src/xfns.c (Fx_create_frame): Ditto. * src/term.c (display_list): Rename to device_list. * src/term.c (initial_display): Rename to initial_device. * src/term.c (next_display_id): Rename to next_device_id. * src/term.c (get_display): Rename to get_device. * src/term.c (get_tty_display): Rename to get_tty_device. * src/term.c (get_named_tty_display): Rename to get_named_tty. * src/term.c (init_initial_display): Rename to init_initial_device. * src/term.c (delete_initial_display): Rename to delete_initial_device. * src/term.c (create_display): Rename to create_device. * src/term.c (delete_display): Rename to delete_device. * src/xfns.c (check_x_display_info): Document that the function allows display ids as well. * src/xterm.c (x_delete_frame_display): Rename to x_delete_device. * src/xterm.c (x_create_frame_display): Rename to x_create_device. * src/coding.c: Update. * src/dispextern.h: Update. * src/data.c: Update. * src/dispnew.c: Update. * src/frame.c: Update. * src/frame.h: Update. * src/keyboard.c: Update. * src/keyboard.h: Update. * src/lisp.h: Update. * src/sysdep.c: Update. * src/term.c: Update. * src/xdisp.c: Update. * src/xselect.c: Update. * src/xterm.c: Update. * src/prefix-args.c: Include stdlib.h for exit. git-archimport-id: lorentey@elte.hu--2004/emacs--multi-tty--0--patch-382
author Karoly Lorentey <lorentey@elte.hu>
date Mon, 11 Jul 2005 00:05:55 +0000
parents 6c13700d1c13
children 532e0a9335a9
line wrap: on
line diff
--- a/src/termhooks.h	Sun Jul 10 22:25:28 2005 +0000
+++ b/src/termhooks.h	Mon Jul 11 00:05:55 2005 +0000
@@ -277,22 +277,22 @@
 #endif /* CONSP */
 
 
-/* Display-local parameters. */
-struct display
+/* Device-local parameters. */
+struct device
 {
-  /* Chain of all displays. */
-  struct display *next_display;
+  /* Chain of all display devices. */
+  struct device *next_device;
 
   /* Unique id for this display. */
   int id;
 
   /* The number of frames that are on this display. */
   int reference_count;
   
   /* The type of the display. */
   enum output_method type;
 
-  /* The name of the display device.  Do not use this to identify the display. */
+  /* The name of the display device.  Do not use this to identify the device. */
   char *name;
 
 #ifdef MULTI_KBOARD
@@ -300,7 +300,7 @@
   struct kboard *kboard;
 #endif
 
   /* Display-type dependent data shared amongst all frames on this display. */
   union display_info
   {
     struct tty_display_info *tty;     /* termchar.h */
@@ -367,8 +367,8 @@
   
   void (*ring_bell_hook) P_ ((struct frame *f));
   
-  void (*reset_terminal_modes_hook) P_ ((struct display *));
-  void (*set_terminal_modes_hook) P_ ((struct display *));
+  void (*reset_terminal_modes_hook) P_ ((struct device *));
+  void (*set_terminal_modes_hook) P_ ((struct device *));
 
   void (*update_begin_hook) P_ ((struct frame *));
   void (*update_end_hook) P_ ((struct frame *));
@@ -498,7 +498,7 @@
 
   /* Called to read input events.
 
-     DISPLAY indicates which display to read from.  Input events
+     DEVICE indicates which display device to read from.  Input events
      should be read into BUF, the size of which is given in SIZE.
      EXPECTED is non-zero if the caller suspects that new input is
      available.
@@ -507,7 +507,7 @@
      where read into BUF.
      Zero means no events were immediately available.
      A value of -1 means a transient read error, while -2 indicates
-     that the display was closed (hangup), and it should be deleted.
+     that the device was closed (hangup), and it should be deleted.
 
      XXX Please note that a non-zero value of EXPECTED only means that
      there is available input on at least one of the currently opened
@@ -515,7 +515,7 @@
      Therefore, in most cases EXPECTED should be simply ignored.
 
      XXX This documentation needs to be updated.  */
-  int (*read_socket_hook) P_ ((struct display *display,
+  int (*read_socket_hook) P_ ((struct device *device,
                                int expected,
                                struct input_event *hold_quit));
 
@@ -524,43 +524,43 @@
 
 
   /* Called to delete the device-specific portions of a frame that is
-     on this display. */
+     on this display device. */
   void (*delete_frame_hook) P_ ((struct frame *));
 
   /* Called after the last frame on this display is deleted, or when
      the display device was closed (hangup).
      
-     If this is NULL, then the generic delete_display is called
-     instead.  Otherwise the hook must call delete_display itself.
+     If this is NULL, then the generic delete_device is called
+     instead.  Otherwise the hook must call delete_device itself.
 
      The hook must check for and close any live frames that are still
-     on the display.  Fdelete_frame ensures that there are no live
-     frames on the display when it calls this hook, so infinite
+     on the device.  Fdelete_frame ensures that there are no live
+     frames on the device when it calls this hook, so infinite
      recursion is prevented.  */
-  void (*delete_display_hook) P_ ((struct display *));
+  void (*delete_device_hook) P_ ((struct device *));
 };
 
 
-/* Chain of all displays currently in use. */
-extern struct display *display_list;
+/* Chain of all display devices currently in use. */
+extern struct device *device_list;
 
-#define FRAME_MUST_WRITE_SPACES(f) ((f)->display->must_write_spaces)
-#define FRAME_FAST_CLEAR_END_OF_LINE(f) ((f)->display->fast_clear_end_of_line)
-#define FRAME_LINE_INS_DEL_OK(f) ((f)->display->line_ins_del_ok)
-#define FRAME_CHAR_INS_DEL_OK(f) ((f)->display->char_ins_del_ok)
-#define FRAME_SCROLL_REGION_OK(f) ((f)->display->scroll_region_ok)
-#define FRAME_SCROLL_REGION_COST(f) ((f)->display->scroll_region_cost)
-#define FRAME_MEMORY_BELOW_FRAME(f) ((f)->display->memory_below_frame)
+#define FRAME_MUST_WRITE_SPACES(f) ((f)->device->must_write_spaces)
+#define FRAME_FAST_CLEAR_END_OF_LINE(f) ((f)->device->fast_clear_end_of_line)
+#define FRAME_LINE_INS_DEL_OK(f) ((f)->device->line_ins_del_ok)
+#define FRAME_CHAR_INS_DEL_OK(f) ((f)->device->char_ins_del_ok)
+#define FRAME_SCROLL_REGION_OK(f) ((f)->device->scroll_region_ok)
+#define FRAME_SCROLL_REGION_COST(f) ((f)->device->scroll_region_cost)
+#define FRAME_MEMORY_BELOW_FRAME(f) ((f)->device->memory_below_frame)
 
-#define FRAME_TERMINAL_CODING(f) ((f)->display->terminal_coding)
-#define FRAME_KEYBOARD_CODING(f) ((f)->display->keyboard_coding)
+#define FRAME_TERMINAL_CODING(f) ((f)->device->terminal_coding)
+#define FRAME_KEYBOARD_CODING(f) ((f)->device->keyboard_coding)
 
-#define DISPLAY_TERMINAL_CODING(d) ((d)->terminal_coding)
-#define DISPLAY_KEYBOARD_CODING(d) ((d)->keyboard_coding)
+#define DEVICE_TERMINAL_CODING(d) ((d)->terminal_coding)
+#define DEVICE_KEYBOARD_CODING(d) ((d)->keyboard_coding)
 
-#define FRAME_RIF(f) ((f)->display->rif)
+#define FRAME_RIF(f) ((f)->device->rif)
 
-#define FRAME_DISPLAY(f) ((f)->display)
+#define FRAME_DEVICE(f) ((f)->device)
 
 /* FRAME_WINDOW_P tests whether the frame is a window, and is
    defined to be the predicate for the window system being used.  */
@@ -578,14 +578,14 @@
 #define FRAME_WINDOW_P(f) (0)
 #endif
 
 /* Return true if the display is not suspended. */
 #define DISPLAY_ACTIVE_P(d) ((d)->type != output_termcap || (d)->display_info.tty->input)
 
-extern struct display *create_display P_ ((void));
-extern void delete_display P_ ((struct display *));
+extern struct device *create_device P_ ((void));
+extern void delete_device P_ ((struct device *));
 
 /* The initial display device, created by initial_term_init. */
-extern struct display *initial_display;
+extern struct device *initial_device;
 
 /* arch-tag: 33a00ecc-52b5-4186-a410-8801ac9f087d
    (do not change this comment) */
@@ -277,22 +277,22 @@
 
-  /* Unique id for this display. */
+  /* Unique id for this display device. */
   int id;
 
@@ -277,22 +277,22 @@
   int id;
 
-  /* The number of frames that are on this display. */
+  /* The number of frames that are on this device. */
   int reference_count;
   
@@ -277,22 +277,22 @@
   int reference_count;
   
-  /* The type of the display. */
+  /* The type of the display device. */
   enum output_method type;
 
@@ -300,7 +300,7 @@
 #endif
 
-  /* Display-type dependent data shared amongst all frames on this display. */
+  /* Device-type dependent data shared amongst all frames on this display. */
   union display_info
   {
@@ -524,43 +524,43 @@
   void (*delete_frame_hook) P_ ((struct frame *));
 
-  /* Called after the last frame on this display is deleted, or when
+  /* Called after the last frame on this device is deleted, or when
      the display device was closed (hangup).
      
@@ -578,14 +578,14 @@
 #endif
 
-/* Return true if the display is not suspended. */
-#define DISPLAY_ACTIVE_P(d) ((d)->type != output_termcap || (d)->display_info.tty->input)
+/* Return true if the display device is not suspended. */
+#define DEVICE_ACTIVE_P(d) ((d)->type != output_termcap || (d)->display_info.tty->input)
 